@@ -1,3 +1,6 @@
+"""Common exceptions for this factory."""
+
+
 class NoSpecsForVariable(Exception):
     """Raise when attempting to access specs of an unknown variable in template."""
 
@@ -7,8 +10,13 @@ class MalformedTemplate(Exception):
 
 
 class NoOrEmptyQueryException(Exception):
-    """Raise when templator has no query or empty query."""
+    """Raise when factory has no query or empty query."""
 
 
 class MissingOrExtraVariableException(Exception):
-    """Raise when templator is given more or less variables than explicitly specified in template."""
+    """Raise when factory is given more or less variables than explicitly specified in
+    template."""
+
+
+class FetchTemplateError(Exception):
+    """Raise when template cannot be fetched from url."""
